/**
 * we wait for the end of the loading of the article edition popup before injecting the webcomponent in order to avoid problems with mounting/unmounting the webcomponent (and random behavior on the react side).
 * if you need to inject information from the drupal backend, you can go through "drupalSettings" https://www.drupal.org/docs/develop/creating-modules/adding-assets-css-js-to-a-drupal-module-via-librariesyml#configurable
 * @type {{attach: Drupal.behaviors.addKeepickerWebComponentMarkup.attach}}
 */
(function (Drupal, drupalSettings) {
  Drupal.behaviors.addKeepickerWebComponentMarkup = {
    attach: function (context) {
      let keepickerContainer = document.querySelector("#kpk-keepicker-container");
      if ((context.id === "node-article-edit-form" || context.id ==="media-library-content" || context.id ==="media-library-wrapper") && keepickerContainer !== null) {
        // For some reason Drupal attach and detach form while opening media library popup
        // Use a setTimeout to avoid adding and removing web component from the DOM because
        // React generates a 409 error (Cannot update an unmounted root)
        setTimeout(() => {
          document.querySelector("#kpk-keepicker-container").innerHTML =
          '<kpk-keepicker '
            + 'id="keepicker" '
            + 'api-endpoint="' + drupalSettings.keepeek.api_endpoint + '" '
            + 'keycloak-client-id="' + drupalSettings.keepeek.keycloak_client_id + '" '
            + 'keycloak-idp="' + drupalSettings.keepeek.keycloak_idp + '" '
            + 'data-locale="' + drupalSettings.keepeek.data_locale + '" '
            + 'ui-locale="' + drupalSettings.keepeek.ui_locale + '" '
            + '></kpk-keepicker>';

        addKeepickerEventListener("kpk-insert");
        addKeepickerEventListener("kpk-insert-link");
        const drupalModal = document.getElementById('drupal-modal');        
        if (drupalModal) {
          //To scroll at top when user is not connected to Keepicker so to see authentification box. See https://jira.keepeek.com/browse/RF-2811
          drupalModal.scrollTop = 0;
        }
        }, 1);
      }
    },
  };
})(Drupal, drupalSettings);

/**
 * Drupal behavior to resize the media library dialog.
 * This behavior is attached to the window object and listens for the "dialog:beforecreate" event.
 * When this event is triggered, it checks if the dialog being created is the media library widget modal.
 * If it is, it sets the height and width of the dialog to 95% of the window's height and width respectively.
 * It also sets up a resize function to adjust the dialog's height when the window is resized.
 * This resize function is removed when the dialog is closed.
 *
 * @param {Object} Drupal - The Drupal object.
 */
(function(Drupal) {
  Drupal.behaviors.resizeMediaLibraryDialog = {
    attach: function(context) {
      // Listen for the "dialog:beforecreate" event on the window object.
      $(window).on("dialog:beforecreate", function(event, dialog, $element, settings) {
        // Check if the dialog being created is the media library widget modal.
        if (settings.dialogClass === "media-library-widget-modal") {
          // Set the height and width of the dialog to 95% of the window's height and width respectively.
          settings.height = $(window).height() * 0.95; // can't apply height in %, due to jquery-ui dialog limitation
          settings.width = "95%";

          // Define a resize function to adjust the dialog's height when the window is resized.
          var resizeFunction = function() {
            if ($element) {
              $element.dialog("option", "height", $(window).height() * 0.95);
            }
          };

          // Attach the resize function to the window's "resize" event.
          $(window).on("resize", resizeFunction);

          // Remove the resize function when the dialog is closed.
          $element.on("dialogclose", function() {
            $(window).off("resize", resizeFunction);
          });
        }
      });
    }
  };
})(Drupal);

function addKeepickerEventListener(type) {
  document
    .querySelector("#keepicker")
    .addEventListener(type, (event) => {
      setKeepickerFormValues(
        'link' in event.detail
          ? event.detail.link
          : event.detail.element.permalinks.find(permalink => permalink.title === "whr").url,
        JSON.stringify(event.detail.element)
      );
    });
}

function setKeepickerFormValues(url, json) {
  document.querySelector(".keepicker-url").value = url;
  document.querySelector(".keepicker-json").value = json;
  submitForm();
}

function submitForm() {
  document
    .querySelector("#media-library-add-form-wrapper input.form-submit")
    .click();
}
